camelot.camelot.view.controls.animation.Throbber

Package camelot :: Package camelot :: Package view :: Package controls :: Module animation :: Class Throbber |
[hide private]
[frames] | no frames]

# Class Throbber

source code

Spinning widget subclassing MovieWidget

Instance Methods | [hide private]
__init__(self, parent) | source code
_idle_state(self) | source code
process_working(self) | source code
process_idle(self) | source code
Inherited from `MovieWidget`: `startMovie`, `stopMovie`, `timerEvent` Inherited from `MovieWidget` (private): `_create_pixmaps`

Method Details | [hide private]

### __init__(self, parent) (Constructor) | source code
Overrides: MovieWidget.__init__